/* ctidaglib.h - CTI DAG board Application Programming Interface */

/*
Copyright (c) 2012, CTI, Connect Tech Inc. All Rights Reserved.

THIS IS THE UNPUBLISHED PROPRIETARY SOURCE CODE OF CONNECT TECH INC.
The copyright notice above does not evidence any actual or intended
publication of such source code.

This module contains Proprietary Information of Connect Tech Inc
and should be treated as Confidential.

--------------------------------------------------------------------
*/

#ifndef _ctidaglib_H
#define _ctidaglib_H

#define	CHANNEL0 0
#define CHANNEL1 1
#define CHANNEL2 2
#define CHANNEL3 3
#define CHANNEL4 4
#define CHANNEL5 5
#define CHANNEL6 6
#define CHANNEL7 7

#define ADC_VP5N5		0 // +-5V
#define ADC_VP10N10		1 // +-10V
#define ADC_VP5			2 // +5V
#define ADC_VP10		3 // +10V

#define	ADC0		0
#define ADC1		1
#define ADC2		2
#define ADC3		3

#define MAX_ADC			3	
#define MAX_SINGLE_CH		7	
#define MAX_DIFF_CH		3	
#define MAX_INPUT_RANGE		3	

#define	DAC0		0
#define DAC1		1
#define DAC2		2
#define DAC3		3
#define DAC_ALL	0x0f

#define DAC_VP5			0 // +5V
#define DAC_VP10		1 // +10V
#define DAC_VP5N5		2 // +-5V
#define DAC_VP10N10		3 // +-10V
#define DAC_VP25N25		4 // +-2.5V
#define DAC_VP75N25		5 // -2.5 to +7.5V

#define CTI_STATUS_OK         		0x000
#define PARAM1_INVALID			0x100
#define PARAM2_INVALID			0x101
#define PARAM3_INVALID			0x102
#define PARAM4_INVALID			0x103
#define PARAM5_INVALID			0x104
#define PARAM6_INVALID			0x105
#define ADC_NOT_INIT				0x106
#define DAC_NOT_INIT				0x107
#define NO_DAG_BOARD				0x108
#define NOT_DAG_BOARD				0x109
#define IO_FAIL					0x10a

#ifndef CTIUFPGABOARD
#define CTIUFPGABOARD
typedef union _CtiUfpgaBoard
{
	int fd; // file descriptor 
}CtiUfpgaBoard;
#endif

/***************************************************************************
* ConnectDAGBoard 
*
* This routine is used to connect to the DAG board
* Arguments:
*			brdInfo - the pointer to CtiUfpgaBoard structure variable 
*			index - index to board, should be 0 unless there are multiple boards in the system 
*
* Returns:
*   If it succeeds then it returns CTI_STATUS_OK otherwise returns error.
*/
int ConnectDAGBoard(CtiUfpgaBoard *brdInfo, int index);

/***************************************************************************
* DisconnectDAGBoard
* This routine is used to disconnect to the DAG board
* Arguments:
*                       brdInfo - the pointer to CtiUfpgaBoard structure variable  
*
* Returns:
*   If it succeeds then it returns CTI_STATUS_OK otherwise returns error.
*/
int DisconnectDAGBoard(CtiUfpgaBoard *brdInfo);

/***************************************************************************
* SetAdcCmd 
*
* This routine is used to configure the ADC port
* Arguments:
*			brdInfo - CtiUfpgaBoard structure variable  
*			index - index to ADC port, index is from ADC0 to ADC3
*			singleEnded - Boolean value to indicate whether the input is single ended
*			channel - channel of the input, the value range is from CHANNEL0 to CHANNEL7
*			polarity - Boolean value to indicate whether the input is not differntial
*			inputRange - input range of ADC, the value range is from ADC_VP5N5 to ADC_VP10
*
* Returns:
*   If it succeeds then it returns CTI_STATUS_OK otherwise returns error.
*/
int SetAdcCmd(CtiUfpgaBoard brdInfo, unsigned char index, unsigned char singleEnded, unsigned char channel, unsigned char polarity, unsigned char inputRange);

/***************************************************************************
* ReadAdc 
*
* This routine is used to read the value from an ADC port
* Arguments:
*			brdInfo - CtiUfpgaBoard structure variable  
*			index - index to ADC port, index is from ADC0 to ADC3
*			value - pointer to the read value
*
* Returns:
*   If it succeeds then it returns CTI_STATUS_OK otherwise returns error.
*/
int ReadAdc(CtiUfpgaBoard brdInfo, int index, float *value);
/***************************************************************************
* SetConfigDac 
*
* This routine is used to configure the DAC port
* Arguments:
*			brdInfo - CtiUfpgaBoard structure variable  
*			index - index to DAC port, index is from DAC0 to DAC_ALL
*			range - output range of DAC, the value range is from DAC_VP5 to DAC_VP75N25
*
* Returns:
*   If it succeeds then it returns CTI_STATUS_OK otherwise returns error.
*/
int SetConfigDac(CtiUfpgaBoard brdInfo, unsigned char index, unsigned char range);

/***************************************************************************
* WriteDAC 
*
* This routine is used to output an DAC port
* Arguments:
*			brdInfo - CtiUfpgaBoard structure variable  
*			index - index to DAC port, index is from DAC0 to DAC_ALL
*			value - output value
*
* Returns:
*   If it succeeds then it returns CTI_STATUS_OK otherwise returns error.
*/
int WriteDAC(CtiUfpgaBoard brdInfo, unsigned char index, float value);

/***************************************************************************
* SetGPIO 
*
* This routine is used to set the direction of the GPIO
* Arguments:
*			brdInfo - CtiUfpgaBoard structure variable  
*			direction - bit value of the direction
*
* Returns:
*   If it succeeds then it returns CTI_STATUS_OK otherwise returns error.
*/
int SetGPIO(CtiUfpgaBoard brdInfo, unsigned short direction);

/***************************************************************************
* SetGPIO 
*
* This routine is used to get the input of the GPIO
* Arguments:
*			brdInfo - CtiUfpgaBoard structure variable  
*			value - Pointer to bit value
*
* Returns:
*   If it succeeds then it returns CTI_STATUS_OK otherwise returns error.
*/
int InputGPIO(CtiUfpgaBoard brdInfo, unsigned short *value);

/***************************************************************************
* SetGPIO 
*
* This routine is used to set the output of the GPIO
* Arguments:
*			brdInfo - CtiUfpgaBoard structure variable  
*			value - bit value of the output
*
* Returns:
*   If it succeeds then it returns CTI_STATUS_OK otherwise returns error.
*/
int OutputGPIO(CtiUfpgaBoard brdInfo, unsigned short value);

#endif
